@@ -50,7 +50,7 @@ $lang = array_merge($lang, array(
 	'DELETE_TIME'	=> 'Omejitev časa za izbris',
 	'DELETE_TIME_EXPLAIN'	=> 'Omeji čas, katerega imajo uporabniki na voljo za izbris nove objave. Nastavitev vrednosti na 0, to funkcijo onemogoči.',
 	'MIN_CHAR_LIMIT'	=> 'Minimalno znakov na objavo/ZS',
-	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Minimalno število znakov, katere mora uporabnik vnesti v objavo/zasebno sporočilo.',
+	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Minimalno število znakov, katere mora uporabnik vnesti v objavo/zasebno sporočilo. Najmanjše možno število je 1.',
 	'SMILIES_PER_PAGE'	=> 'Smeškov na stran',
 	'NEW_MEMBER_POST_LIMIT'	=> 'Limit objav novih članov',
 	'NEW_MEMBER_POST_LIMIT_EXPLAIN'	=> 'Novo Registrirani uporabniki so v skupini <em>Novo Registrirani Uporabniki</em> dokler ne dosežejo tega števila objav. Lahko uporabiš to skupino za onemogočanje ZS ali da priklicujejo svoje objave. <strong>Vrednost 0 onemogoči to funkcijo.</strong>',
@@ -107,7 +107,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_DST'	=> 'Omogoči poletni čas (DST)',
 	'SYSTEM_TIMEZONE'	=> 'Izberi časovni pas',
 	'WARNINGS_EXPIRE'	=> 'Trajanje opozorila',
-	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Število dni, ki naj preteče, preden uporabniška opozorila avtomatsko pretečejo.',
+	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Število dni, ki naj preteče, preden uporabniška opozorila avtomatsko pretečejo. Nastavi na 0, da ne pretečejo nikoli.',
 	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'Tu lahko nastavljaš številne nastavitve foruma.',
 	'ALLOW_ATTACHMENTS'	=> 'Omogoči priponke',
 	'ALLOW_BIRTHDAYS'	=> 'Omogoči rojstne dneve',
