@@ -130,7 +130,7 @@ $lang = array_merge($lang, array(
 	'ACP_MANAGE_EXTENSIONS'	=> 'Uredi končnice',
 	'ACP_MANAGE_FORUMS'	=> 'Urejaj forume',
 	'ACP_MANAGE_RANKS'	=> 'Uredi stopnje uporabnikov',
-	'ACP_MANAGE_REASONS'	=> 'Uredi razloge poročil/preklica',
+	'ACP_MANAGE_REASONS'	=> 'Uredi razloge poročil/prijav',
 	'ACP_MANAGE_USERS'	=> 'Uredi uporabnike',
 	'ACP_MASS_EMAIL'	=> 'Množična e-pošta',
 	'ACP_MESSAGES'	=> 'Sporočila',
@@ -284,6 +284,15 @@ $lang = array_merge($lang, array(
 	'BOARD_VERSION'	=> 'Verzija foruma',
 	'DATABASE_SERVER_INFO'	=> 'Server podatkovne baze',
 	'DATABASE_SIZE'	=> 'Velikost podatkovne baze',
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Funkcija za preobremenitev je nepravilno nastavljena',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> mora biti nastavljena na 0 ali 4. Trenutno vrednost lahko preverite  na <samp>PHP information</samp> strani.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Prosojnost znaka je nepravilno nastavljena',	
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> mora biti nastavljeno na 0. Trenutno vrednost lahko preverite  na <samp>PHP information</samp> strani.',	
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP pretvorba vhodnih znakov mora biti pravilno nastavljena',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> mora biti nastavljeno na <samp>pass</samp>. Trenutno vrednost lahko preverite  na <samp>PHP information</samp> strani.',	
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP pretvorba izhodnih znakov mora biti pravilno nastavljena',	
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> mora biti nastavljeno na <samp>pass</samp>. Trenutno vrednost lahko preverite  na <samp>PHP information</samp> strani.',
 	'FILES_PER_DAY'	=> 'Priponk na dan',
 	'FORUM_STATS'	=> 'Statistika foruma',
 	'GZIP_COMPRESSION'	=> 'GZip kompresija',
