@@ -37,8 +37,8 @@ if (empty($lang) || !is_array($lang))
 // in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
 
 $lang = array_merge($lang, array(
-	'ROLE_FORUM_NEW_MEMBER'	=> 'Novo registrirani uporabnik',
-	'ROLE_USER_NEW_MEMBER'	=> 'Novo registrirani uporabnik',
+	'ROLE_FORUM_NEW_MEMBER'	=> 'Novo registrirani uporabniški dostop',
+	'ROLE_USER_NEW_MEMBER'	=> 'Funkcije novo registriranega uporabnika',
 	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'	=> 'Vloga članov novo registriranih uporabnikov; ne vsebuje <samp>NIKOLI</samp> dovoljenj za zaklepanje funkcij za nove uporabnike.',
 	'ROLE_DESCRIPTION_USER_NEW_MEMBER'	=> 'Vloga članov novo registriranih uporabnikov; ne vsebuje <samp>NIKOLI</samp> dovoljenj za zaklepanje funkcij za nove uporabnike.',
 	'ACP_PERMISSIONS_EXPLAIN'	=> '		<p>Dovoljenja so strnjena v štiri glavne skupine:</p>
