@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'	=> 'Če želite poslati sporočilo, morate napisati Zadevo',
 	'ENABLED'	=> 'Omogočeno',
 	'ENCLOSURE'	=> 'Pripni',
+	'ENTER_USERNAME' => 'Vnesite ime',
 	'ERR_CHANGING_DIRECTORY'	=> 'Menjava direktorijev ni mogoča.',
 	'ERR_CONNECTING_SERVER'	=> 'Ne morem se povezati na strežnik.',
 	'ERR_JAB_AUTH'	=> 'Avtorizacija z Jabber strežnikom ni uspela.',
@@ -178,7 +179,7 @@ $lang = array_merge($lang, array(
 	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'Razširitev <strong>%s</strong> Je bila deaktivirana in je ni mogoče prikazati.',
 	
 	'FAQ'	=> 'FAQ',
-	'FAQ_EXPLAIN'	=> 'Že zastavljena vprašanja',
+	'FAQ_EXPLAIN'	=> 'Pogosto zastavljena vprašanja',
 	'FILENAME'	=> 'Ime datoteke',
 	'FILESIZE'	=> 'Velikost datoteke',
 	'FILEDATE'	=> 'Datum datoteke',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'Klikni tukaj za prikaz pravil na forumu',
 	'FROM'	=> 'od',
 	'FSOCK_DISABLED'	=> 'Operacije ni bilo mogoče dokončati, saj je bila funkcija <var>fsockopen</var> onemogočena ali pa strežnika, ki ga iščete, ni mogoče najti.',
+	'FSOCK_TIMEOUT'			=> 'Povezava je potekla med branjem spletnega toka.',
 	
 	'FTP_FSOCK_HOST'	=> 'FTP strežnik',
 	'FTP_FSOCK_HOST_EXPLAIN'	=> 'FTP strežnik uporabljen za povezavo na vašo stran.',
@@ -652,6 +654,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'	=> '<strong>%d</strong> neprebranih sporočil',
 	'UNREAD_POST'	=> 'Neprebrana objava',
 	'UNREAD_POSTS'	=> 'Neprebrane objave',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Ali si prepričan/a, da ne želiš več spremljati novih objav na forumu?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Ali si prepričan/a, da ne želiš več spremljati novih objav na forumu “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Ali si prepričan/a, da ne želiš več spremljati novih objav na tej temi?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Ali si prepričan/a, da ne želiš več spremljati novih objav na temi “%s”?',
 	'UNWATCHED_FORUMS'	=> 'Ne spremljaš več izbranih forumov.',
 	'UNWATCHED_TOPICS'	=> 'Ne spremljaš več izbranih tem.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Niste več naročeni na izbrane prispevke.',
@@ -700,6 +706,10 @@ $lang = array_merge($lang, array(
 	
 	'WARNINGS'	=> 'Opozorila',
 	'WARN_USER'	=> 'Opozori uporabnika',
+	'WATCH_FORUM_CONFIRM'	=> 'Ali si prepričan/a, da želiš spremljati nove objave na forumu?',
+	'WATCH_FORUM_DETAILED'	=> 'Ali si prepričan/a, da želiš spremljati nove objave na forumu “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Ali si prepričan/a, da želiš spremljati nove objave na tej temi?',
+	'WATCH_TOPIC_DETAILED'	=> 'Ali si prepričan/a, da želiš spremljati nove objave na temi “%s”?',
 	'WELCOME_SUBJECT'	=> 'Dobrodošli na forum %s',
 	'WEBSITE'	=> 'Spletna stran',
 	'WHOIS'	=> 'Whois',
