@@ -66,8 +66,7 @@ $help = array(
 	),
 	array(
 		0	=> 'Že pred časom sem se registriral, a se naenkrat ne morem več prijaviti?!',
-		1	=> 'Poskusite najdi elektronsko sporočilo, ki ste ga prejeli ob vaši prvi registraciji in preverite vaše uporabniško ime in geslo ter poskusite znova. Možno je, da je administrator z nekim razlogom deaktiviral ali izbrisal vaš račun. Veliko forumov je tudi nastavljenih tako, da odstranijo uporabnike, ki dolgo časa ne objavijo ničesar, saj se tako zmanjša baza podatkov. Če se je zgodilo slednje, se poskušajte ponovno registrirati in biti v prihodnje bolj udeleženi v debatah.
-',
+		1	=> 'Možno je, da so administratorji onemogočili ali izbrisali Vaš račun. Marsikateri forum avtomatsko deaktivira uporabnike, kateri niso dosti časa aktivni. Če se je to zgodilo, se ponovno registrirati in poizkusite biti bolj aktivni na forumu.',
 	),
 	array(
 		0	=> 'Kaj je COPPA?',
