@@ -138,6 +138,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'	=> 'Trenutna slika',
 	'CURRENT_PASSWORD'	=> 'Trenutno geslo',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Če želite spremeniti svoje geslo, uporabniško ime ali e-naslov, morate potrditi trenutno geslo.',
+	'CUR_PASSWORD_EMPTY'		=> 'Niste vnesli trenutnega aktivnega gesla.',
 	'CUR_PASSWORD_ERROR'	=> 'Trenutno geslo, ki ste ga vnesli, ni pravilno',
 	'CUSTOM_DATEFORMAT'	=> 'Po meri…',
 	'DEFAULT_ACTION'	=> 'Privzeta akcija',
@@ -254,9 +255,12 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'	=> 'Napaka pri premikanju sporočil - samo %1d od %2d sporočil je bilo premaknjenih.',
 	'MOVE_TO_FOLDER'	=> 'Premakni v mapo',
 	'MOVE_UP'	=> 'Pomakni gor',
+	
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Niste vnesli potrjen e-naslov.',
 	'NEW_EMAIL_ERROR'	=> 'Vpisana e-naslova se ne ujemata.',
 	'NEW_FOLDER_NAME'	=> 'Novo ime mape',
 	'NEW_PASSWORD'	=> 'Novo geslo',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Niste vnesli potrjeno geslo.',
 	'NEW_PASSWORD_ERROR'	=> 'Gesli, ki ste ju vpisali, se ne ujemata.',
 	'NOTIFY_METHOD'	=> 'Način obveščanja',
 	'NOTIFY_METHOD_BOTH'	=> 'Oboje',
